pub struct SharedRwLock {
cell: Option<Arc<AtomicRefCell<SomethingZeroSizedButTyped>>>,
}Expand description
A shared read/write lock that can protect multiple objects.
We don’t need the blocking behavior, just the safety. As such we implement this with an AtomicRefCell, which is ~2x as fast as an RwLock, and panics (rather than deadlocking) when things go wrong (which is much easier to debug on CI).
Gecko also needs the ability to have “read only” SharedRwLocks, which are used for objects stored in (read only) shared memory. Attempting to acquire write access to objects protected by a read only SharedRwLock will panic.
Fields
cell: Option<Arc<AtomicRefCell<SomethingZeroSizedButTyped>>>Implementations
Sourcepub fn new_leaked() -> Self
pub fn new_leaked() -> Self
Create a new global shared lock.
fn ptr(&self) -> *const SomethingZeroSizedButTyped
Sourcepub fn wrap<T>(&self, data: T) -> Locked<T>
pub fn wrap<T>(&self, data: T) -> Locked<T>
Wrap the given data to make its access protected by this lock.
Sourcepub fn read(&self) -> SharedRwLockReadGuard<'_>
pub fn read(&self) -> SharedRwLockReadGuard<'_>
Obtain the lock for reading.
Sourcepub fn write(&self) -> SharedRwLockWriteGuard<'_>
pub fn write(&self) -> SharedRwLockWriteGuard<'_>
Obtain the lock for writing.